@@ -253,7 +253,7 @@ KateGlobalConfig::KateGlobalConfig()
                                    return isEncodingOk(value.toString());
                                }));
 
-    // finalize the entries, e.g. hashs them
+    // finalize the entries, e.g. hashes them
     finalizeConfigEntries();
 
     // init with defaults from config or really hardcoded ones
@@ -361,10 +361,12 @@ KateDocumentConfig::KateDocumentConfig()
 
     // Shall we do auto reloading for stuff e.g. in Git?
     addConfigEntry(ConfigEntry(AutoReloadIfStateIsInVersionControl, "Auto Reload If State Is In Version Control", QString(), true));
+    addConfigEntry(
+        ConfigEntry(AutoReloadOnExternalChanges, "Auto Reload If Any External Changes Occurs", QStringLiteral("auto-reload-on-external-changes"), false));
     // .editorconfig
     addConfigEntry(ConfigEntry(UseEditorConfig, "Use Editor Config", QString(), true));
 
-    // finalize the entries, e.g. hashs them
+    // finalize the entries, e.g. hashes them
     finalizeConfigEntries();
 
     // init with defaults from config or really hardcoded ones
