@@ -23,6 +23,7 @@
 #include "katedocument.h"
 #include "katehighlightingcmds.h"
 #include "katekeywordcompletion.h"
+#include "katemodelinecompletion.h"
 #include "katemodemanager.h"
 #include "katescriptmanager.h"
 #include "katesedcmd.h"
@@ -60,7 +61,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
                   QStringLiteral(KTEXTEDITOR_VERSION_STRING),
                   i18n("Embeddable editor component"),
                   KAboutLicense::LGPL_V2,
-                  i18n("(c) 2000-2022 The Kate Authors"),
+                  i18n("(c) 2000-2025 The Kate Authors"),
                   QString(),
                   QStringLiteral("https://kate-editor.org"))
     , m_dummyApplication(nullptr)
@@ -80,19 +81,13 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     //
     // fill about data
     //
-    m_aboutData.addAuthor(i18n("Christoph Cullmann"), i18n("Maintainer"), QStringLiteral("cullmann@kde.org"), QStringLiteral("https://cullmann.io"));
+    m_aboutData.addAuthor(i18n("Christoph Cullmann"), i18n("Maintainer"), QStringLiteral("cullmann@kde.org"), QStringLiteral("https://cullmann.dev"));
     m_aboutData.addAuthor(i18n("Dominik Haumann"), i18n("Core Developer"), QStringLiteral("dhaumann@kde.org"));
     m_aboutData.addAuthor(i18n("Milian Wolff"), i18n("Core Developer"), QStringLiteral("mail@milianw.de"), QStringLiteral("https://milianw.de/"));
-    m_aboutData.addAuthor(i18n("Joseph Wenninger"),
-                          i18n("Core Developer"),
-                          QStringLiteral("jowenn@kde.org"),
-                          QStringLiteral("http://stud3.tuwien.ac.at/~e9925371"));
+    m_aboutData.addAuthor(i18n("Joseph Wenninger"), i18n("Core Developer"), QStringLiteral("jowenn@kde.org"));
     m_aboutData.addAuthor(i18n("Erlend Hamberg"), i18n("Vi Input Mode"), QStringLiteral("ehamberg@gmail.com"), QStringLiteral("https://hamberg.no/erlend"));
-    m_aboutData.addAuthor(i18n("Bernhard Beschow"),
-                          i18n("Developer"),
-                          QStringLiteral("bbeschow@cs.tu-berlin.de"),
-                          QStringLiteral("https://user.cs.tu-berlin.de/~bbeschow"));
-    m_aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"), QStringLiteral("https://alweb.dk"));
+    m_aboutData.addAuthor(i18n("Bernhard Beschow"), i18n("Developer"), QStringLiteral("bbeschow@cs.tu-berlin.de"));
+    m_aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"));
     m_aboutData.addAuthor(i18n("Michel Ludwig"), i18n("On-the-fly spell checking"), QStringLiteral("michel.ludwig@kdemail.net"));
     m_aboutData.addAuthor(i18n("Pascal Létourneau"), i18n("Large scale bug fixing"), QStringLiteral("pascal.letourneau@gmail.com"));
     m_aboutData.addAuthor(i18n("Hamish Rodda"), i18n("Core Developer"), QStringLiteral("rodda@kde.org"));
@@ -115,10 +110,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
                           QStringLiteral("webmaster@hartwork.org"),
                           QStringLiteral("https://hartwork.org/"));
     m_aboutData.addAuthor(i18n("Jochen Wilhelmy"), i18n("Original KWrite Author"), QStringLiteral("digisnap@cs.tu-berlin.de"));
-    m_aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"),
-                          i18n("QA and Scripting"),
-                          QStringLiteral("oss@senarclens.eu"),
-                          QStringLiteral("http://find-santa.eu/"));
+    m_aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"), i18n("QA and Scripting"), QStringLiteral("oss@senarclens.eu"));
 
     m_aboutData.addCredit(i18n("Matteo Merli"), i18n("Highlighting for RPM Spec-Files, Perl, Diff and more"), QStringLiteral("merlim@libero.it"));
     m_aboutData.addCredit(i18n("Rocky Scaletta"), i18n("Highlighting for VHDL"), QStringLiteral("rocky@purdue.edu"));
@@ -205,6 +197,8 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     // global keyword completion model
     m_keywordCompletionModel = new KateKeywordCompletionModel(this);
 
+    m_modelineCompletion = new KateModelineCompletionModel(this);
+
     // tap to QApplication object for color palette changes
     qApp->installEventFilter(this);
 }
@@ -495,8 +489,13 @@ bool KTextEditor::EditorPrivate::eventFilter(QObject *obj, QEvent *event)
 QStringListModel *KTextEditor::EditorPrivate::searchHistoryModel()
 {
     if (!m_searchHistoryModel) {
-        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
-        const QStringList history = cg.readEntry(QStringLiteral("Search History"), QStringList());
+        KConfigGroup cg(KSharedConfig::openStateConfig(), QStringLiteral("KTextEditor::Search"));
+
+        // migrate old non-state data
+        KSharedConfigPtr oldConfig = KSharedConfig::openConfig();
+        oldConfig->group(QStringLiteral("KTextEditor::Search")).moveValuesTo({"Search History"}, cg);
+
+        const QStringList history = cg.readEntry("Search History", QStringList());
         m_searchHistoryModel = new QStringListModel(history, this);
     }
     return m_searchHistoryModel;
@@ -505,8 +504,13 @@ QStringListModel *KTextEditor::EditorPrivate::searchHistoryModel()
 QStringListModel *KTextEditor::EditorPrivate::replaceHistoryModel()
 {
     if (!m_replaceHistoryModel) {
-        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
-        const QStringList history = cg.readEntry(QStringLiteral("Replace History"), QStringList());
+        KConfigGroup cg(KSharedConfig::openStateConfig(), QStringLiteral("KTextEditor::Search"));
+
+        // migrate old non-state data
+        KSharedConfigPtr oldConfig = KSharedConfig::openConfig();
+        oldConfig->group(QStringLiteral("KTextEditor::Search")).moveValuesTo({"Replace History"}, cg);
+
+        const QStringList history = cg.readEntry("Replace History", QStringList());
         m_replaceHistoryModel = new QStringListModel(history, this);
     }
     return m_replaceHistoryModel;
@@ -514,12 +518,12 @@ QStringListModel *KTextEditor::EditorPrivate::replaceHistoryModel()
 
 void KTextEditor::EditorPrivate::saveSearchReplaceHistoryModels()
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
+    KConfigGroup cg(KSharedConfig::openStateConfig(), QStringLiteral("KTextEditor::Search"));
     if (m_searchHistoryModel) {
-        cg.writeEntry(QStringLiteral("Search History"), m_searchHistoryModel->stringList());
+        cg.writeEntry("Search History", m_searchHistoryModel->stringList());
     }
     if (m_replaceHistoryModel) {
-        cg.writeEntry(QStringLiteral("Replace History"), m_replaceHistoryModel->stringList());
+        cg.writeEntry("Replace History", m_replaceHistoryModel->stringList());
     }
 }
 
@@ -559,22 +563,6 @@ void KTextEditor::EditorPrivate::emitConfigChanged()
     }
 }
 
-void KTextEditor::EditorPrivate::copyToMulticursorClipboard(const QStringList &texts)
-{
-    if (texts.size() == 1) {
-        qWarning() << "Unexpected size 1 of multicursorClipboard. It should either be empty or greater than 1";
-        m_multicursorClipboard = QStringList();
-        Q_ASSERT(false);
-        return;
-    }
-    m_multicursorClipboard = texts;
-}
-
-QStringList KTextEditor::EditorPrivate::multicursorClipboard() const
-{
-    return m_multicursorClipboard;
-}
-
 QTextToSpeech *KTextEditor::EditorPrivate::speechEngine(KTextEditor::ViewPrivate *view)
 {
     Q_ASSERT(view);
