@@ -2,6 +2,7 @@
     SPDX-FileCopyrightText: 2004, 2010 Joseph Wenninger <jowenn@kde.org>
     SPDX-FileCopyrightText: 2009 Milian Wolff <mail@milianw.de>
     SPDX-FileCopyrightText: 2014 Sven Brauch <svenbrauch@gmail.com>
+    SPDX-FileCopyrightText: 2025 Mirian Margiani <mixosaurus+kde@pm.me>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +17,9 @@
 
 #include <katescript.h>
 #include <ktexteditor/cursor.h>
+#include <ktexteditor/range.h>
 
+class QDebug;
 class KateUndoManager;
 
 namespace KTextEditor
@@ -41,7 +44,7 @@ class View;
  * \li When more than one variable exists,TAB and SHIFT TAB can be used to navigate
  *     to the next/previous variable.
  * \li When a variable occurs more than once in the template, edits to any of the
- *     occurrences will be mirroed to the other ones.
+ *     occurrences will be mirrored to the other ones.
  * \li When ESC is pressed, the template handler closes.
  * \li When ALT + RETURN is pressed and a \c ${cursor} variable
  *     exists in the template,the cursor will be placed there. Else the cursor will
@@ -112,6 +115,8 @@ private:
      * of the TemplateField instances in m_fields from the raw, user-entered
      * default value to its evaluated equivalent (e.g. "func()" -> result of function call)
      *
+     * Default values are subsequently written into the document.
+     *
      * @sa TemplateField
      */
     void setupDefaultValues();
@@ -159,12 +164,6 @@ private:
      */
     void updateRangeBehaviours();
 
-    /**
-     * Sort all template fields in m_fields by tab order, which means,
-     * by range; except for ${cursor} which is always sorted last.
-     */
-    void sortFields();
-
 private Q_SLOTS:
     /**
      * Saves the range of the inserted template. This is required since
@@ -181,7 +180,7 @@ private Q_SLOTS:
     /**
      * Update content of all dependent fields, i.e. mirror or script fields.
      */
-    void updateDependentFields(KTextEditor::Document *document, KTextEditor::Range oldRange);
+    void updateDependentFields(KTextEditor::Document *document, KTextEditor::Range oldRange, bool textRemoved = false);
 
 public:
     KTextEditor::ViewPrivate *view() const;
@@ -195,8 +194,15 @@ private:
 
     // Describes a single template field, e.g. ${foo}.
     struct TemplateField {
+        // unique field ID to identify and order fields
+        qsizetype id{-1};
+
         // up-to-date range for the field
         std::shared_ptr<KTextEditor::MovingRange> range;
+
+        // static range for identifying changes
+        KTextEditor::Range staticRange{KTextEditor::Range::invalid()};
+
         // contents of the field, i.e. identifier or function to call
         QString identifier;
         // default value, if applicable; else empty
@@ -211,16 +217,30 @@ private:
         Kind kind = Invalid;
         // true if this field was edited by the user before
         bool touched = false;
+        // true if this field was removed e.g., because the line that contained it was removed
+        bool removed = false;
+
         bool operator==(const TemplateField &other) const
         {
-            return range == other.range;
+            return id == other.id;
+        }
+
+        friend bool operator<(const TemplateField &l, const TemplateField &r)
+        {
+            return l.id < r.id;
         }
     };
+
     // List of all template fields in the inserted snippet. @see sortFields()
     QList<TemplateField> m_fields;
 
-    // Get the template field which contains @p range.
-    const TemplateField fieldForRange(KTextEditor::Range range) const;
+    // Get all template fields which contain or border on @p range.
+    // If @p compareStaticRanges is @c true, compare with last saved static field
+    // ranges instead of moving field ranges.
+    const QList<TemplateField> fieldsForRange(KTextEditor::Range range, bool compareStaticRanges) const;
+
+    // Restore order of empty adjacent fields after inserting into one.
+    void reorderEmptyAdjacentFields(const QList<TemplateField> &changedFields);
 
     /// Construct a map of master fields and their current value, for use in scripts.
     KateScript::FieldMap fieldMap() const;
