@@ -28,11 +28,18 @@ QStringList reversed(const QStringList &originalList);
 class SearchMode : public ActiveMode
 {
 public:
-    SearchMode(EmulatedCommandBar *emulatedCommandBar, MatchHighlighter *matchHighlighter, InputModeManager *viInputModeManager, KTextEditor::ViewPrivate *view, QLineEdit *edit);
+    SearchMode(EmulatedCommandBar *emulatedCommandBar,
+               MatchHighlighter *matchHighlighter,
+               InputModeManager *viInputModeManager,
+               KTextEditor::ViewPrivate *view,
+               QLineEdit *edit);
     ~SearchMode() override
     {
     }
-    enum class SearchDirection { Forward, Backward };
+    enum class SearchDirection {
+        Forward,
+        Backward
+    };
     void init(SearchDirection);
     bool handleKeyPress(const QKeyEvent *keyEvent) override;
     void editTextChanged(const QString &newText) override;
@@ -50,7 +57,11 @@ private:
     KTextEditor::Cursor m_startingCursorPos;
     KateVi::Searcher::SearchParams m_currentSearchParams;
     CompletionStartParams activateSearchHistoryCompletion();
-    enum BarBackgroundStatus { Normal, MatchFound, NoMatchFound };
+    enum BarBackgroundStatus {
+        Normal,
+        MatchFound,
+        NoMatchFound
+    };
     void setBarBackground(BarBackgroundStatus status);
     bool m_isSendingSyntheticSearchCompletedKeypress = false;
 };
