@@ -12,6 +12,7 @@
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katepartdebug.h"
+#include "katerenderer.h"
 #include "kateview.h"
 #include "kateviewinternal.h"
 #include "kateviinputmode.h"
@@ -288,7 +289,7 @@ bool InsertViMode::commandSwitchToNormalModeForJustOneCommand()
     if (doc()->line(cursorPos.line()).length() == cursorPos.column()) {
         m_view->setCursorPosition(KTextEditor::Cursor(cursorPos.line(), cursorPos.column() - 1));
     }
-    m_viInputModeManager->inputAdapter()->setCaretStyle(KateRenderer::Block);
+    m_viInputModeManager->inputAdapter()->setCaretStyle(KTextEditor::caretStyles::Block);
     Q_EMIT m_view->viewModeChanged(m_view, m_view->viewMode());
     m_viewInternal->repaint();
     return true;
@@ -300,9 +301,13 @@ bool InsertViMode::commandSwitchToNormalModeForJustOneCommand()
  */
 bool InsertViMode::handleKeypress(const QKeyEvent *e)
 {
-    // backspace should work even if the shift key is down
-    if (e->modifiers() != CONTROL_MODIFIER && e->key() == Qt::Key_Backspace) {
-        m_view->backspace();
+    if (e->key() == Qt::Key_Backspace) {
+        // backspace should work even if the shift key is down
+        if (e->modifiers() != CONTROL_MODIFIER) {
+            m_view->backspace();
+        } else {
+            m_view->deleteWordLeft();
+        }
         return true;
     }
 
@@ -583,5 +588,3 @@ void InsertViMode::textInserted(KTextEditor::Document *document, KTextEditor::Ra
         m_textInsertedByCompletionEndPos = range.end();
     }
 }
-
-#include "moc_insertvimode.cpp"
